@@ -24,8 +24,6 @@
 
 #include "bugzilla.h"
 
-#include <glade/glade.h>
-#include <gdk-pixbuf/gdk-pixbuf.h>
 #include <sys/types.h>
 
 
@@ -48,8 +46,8 @@ typedef struct {
 	/* file to include */
 	gchar *include_file;
 
-	/* MiniDump file */
-	gchar *minidump_file;
+	/* whether to own the included file */
+	gboolean own_file;
 
 	/* pid to kill after the bug report */
 	int kill;
